pub struct UnitGuard {
pub symbols: &'static [&'static str],
}Expand description
A check on the span a kind’s pattern matched, where the kind’s standard defines one: the span is a number then one of these unit symbols, attached or one separator apart, so a number and a symbol a line apart are not fused.
Fields
symbols: &'static [&'static str]The symbols the span may end in.
Implementations