pub struct ReportRule<'a> {
pub name: &'a str,
pub severity: &'a str,
pub message: &'a str,
pub fix: &'a str,
}Expand description
The rule a finding is of, for a report’s template to write: its name, its severity, and the message and fix rendered for the finding.
Fields
name: &'a strseverity: &'a strmessage: &'a strfix: &'a strTrait Implementations
Sourceimpl<'a> Clone for ReportRule<'a>
impl<'a> Clone for ReportRule<'a>
impl<'a> Copy for ReportRule<'a>
Sourceimpl<'a> Debug for ReportRule<'a>
impl<'a> Debug for ReportRule<'a>
impl<'a> Eq for ReportRule<'a>
Sourceimpl<'a> PartialEq for ReportRule<'a>
impl<'a> PartialEq for ReportRule<'a>
impl<'a> StructuralPartialEq for ReportRule<'a>